Reference Files
===============
The ``photom`` step uses :ref:`PHOTOM <photom_reffile>`
and pixel :ref:`AREA <area_reffile>` reference files.
The AREA reference file is only used when processing
imaging and NIRSpec IFU observations.

.. include:: ../references_general/photom_reffile.inc

.. include:: ../references_general/area_reffile.inc
